# Excludarr Change History

## 0.1.0

Initial release.

- Rewritten the tool to a full CLI tool
- Add more flexibility by adding flags
- The tool will not delete movies without asking the user

## 0.1.1

Release to PyPi.
